@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-from __future__ import absolute_import, division, print_function, unicode_literals
-
+from .confounds import ExpandModel, SpikeRegressors
 from .masks import BETRPT as BET
 from .segmentation import (FASTRPT as FAST)
 from .registration import (FLIRTRPT as FLIRT,
@@ -12,4 +10,6 @@ from .registration import (FLIRTRPT as FLIRT,
                            ANTSApplyTransformsRPT as ApplyTransforms,
                            SimpleBeforeAfterRPT as SimpleBeforeAfter)
 from .utils import CopyXForm, CopyHeader, NormalizeMotionParams, SanitizeImage
-from .plotting import FMRISummary
+from .plotting import (
+    FMRISummary, CompCorVariancePlot, ConfoundsCorrelationPlot
+)
