@@ -236,7 +236,7 @@ def _gen_reference(fixed_image, moving_image, fov_mask=None, out_file=None,
     new_zooms = reoriented_moving_img.header.get_zooms()[:3]
 
     # Avoid small differences in reported resolution to cause changes to
-    # FOV. See https://github.com/poldracklab/fmriprep/issues/512
+    # FOV. See https://github.com/nipreps/fmriprep/issues/512
     # A positive diagonal affine is RAS, hence the need to reorient above.
     new_affine = np.diag(np.round(new_zooms, 3))
 
@@ -321,7 +321,7 @@ class SanitizeImage(SimpleInterface):
     problematic combinations of values. Removes any extension form the header
     if present.
     This interface implements the `following logic
-    <https://github.com/poldracklab/fmriprep/issues/873#issuecomment-349394544>`_:
+    <https://github.com/nipreps/fmriprep/issues/873#issuecomment-349394544>`_:
     +-------------------+------------------+------------------+------------------\
 +------------------------------------------------+
     | valid quaternions | `qform_code > 0` | `sform_code > 0` | `qform == sform` \
@@ -425,8 +425,11 @@ class SanitizeImage(SimpleInterface):
 </p>
 """
 
-        if (self.inputs.max_32bit and
-                np.dtype(img.get_data_dtype()).itemsize > 4) or self.inputs.n_volumes_to_discard:
+        if (
+            (self.inputs.max_32bit
+             and np.dtype(img.get_data_dtype()).itemsize > 4)
+            or self.inputs.n_volumes_to_discard
+        ):
             # force float32 only if 64 bit dtype is detected
             if (self.inputs.max_32bit and np.dtype(img.get_data_dtype()).itemsize > 4):
                 in_data = img.get_fdata(dtype=np.float32)
@@ -721,7 +724,8 @@ class JoinTSVColumns(SimpleInterface):
         with open(self.inputs.join_file) as ifh:
             join = ifh.read().splitlines(keepends=False)
 
-        assert len(data) == len(join)
+        if len(data) != len(join):
+            raise ValueError("Number of columns in datasets do not match")
 
         merged = []
         for d, j in zip(data, join):
@@ -905,8 +909,10 @@ def _tpm2roi(in_tpm, in_mask, mask_erosion_mm=None, erosion_mm=None,
     roi_mask = (tpm_img.get_fdata() >= pthres).astype(np.uint8)
 
     eroded_mask_file = None
-    erode_in = (mask_erosion_mm is not None and mask_erosion_mm > 0 or
-                mask_erosion_prop is not None and mask_erosion_prop < 1)
+    erode_in = (
+        (mask_erosion_mm is not None and mask_erosion_mm > 0)
+        or (mask_erosion_prop is not None and mask_erosion_prop < 1)
+    )
     if erode_in:
         eroded_mask_file = fname_presuffix(in_mask, suffix='_eroded',
                                            newpath=newpath)
@@ -929,8 +935,10 @@ def _tpm2roi(in_tpm, in_mask, mask_erosion_mm=None, erosion_mm=None,
         roi_mask[~mask_data] = 0
 
     # shrinking
-    erode_out = (erosion_mm is not None and erosion_mm > 0 or
-                 erosion_prop is not None and erosion_prop < 1)
+    erode_out = (
+        (erosion_mm is not None and erosion_mm > 0)
+        or (erosion_prop is not None and erosion_prop < 1)
+    )
     if erode_out:
         if erosion_mm:
             iter_n = max(int(erosion_mm / max(tpm_img.header.get_zooms())), 1)
