@@ -234,7 +234,7 @@ class Report(object):
     >>> robj.generate_report()
     0
     >>> len((testdir / 'out' / 'fmriprep' / 'sub-01.html').read_text())
-    36425
+    36450
 
     .. testcleanup::
 
@@ -378,7 +378,7 @@ class Report(object):
 
         env = jinja2.Environment(
             loader=jinja2.FileSystemLoader(searchpath=str(self.template_path.parent)),
-            trim_blocks=True, lstrip_blocks=True
+            trim_blocks=True, lstrip_blocks=True, autoescape=False
         )
         report_tpl = env.get_template(self.template_path.name)
         report_render = report_tpl.render(sections=self.sections, errors=self.errors,
