@@ -8,9 +8,11 @@ Helpers for handling BIDS-like neuroimaging structures
 
 """
 from pathlib import Path
-import warnings
+import json
 import re
+import warnings
 from bids import BIDSLayout
+from packaging.version import Version
 
 __all__ = ['BIDS_NAME']
 
@@ -119,7 +121,7 @@ def collect_participants(bids_dir, participant_label=None, strict=False,
 
 
 def collect_data(bids_dir, participant_label, task=None, echo=None,
-                 bids_validate=True):
+                 bids_validate=True, bids_filters=None):
     """
     Uses pybids to retrieve the input data for a given participant
     >>> bids_root, _ = collect_data(str(datadir / 'ds054'), '100185',
@@ -146,6 +148,10 @@ def collect_data(bids_dir, participant_label, task=None, echo=None,
     ['.../ds054/sub-100185/anat/sub-100185_T1w.nii.gz']
     >>> bids_root['t2w']  # doctest: +ELLIPSIS
     []
+    >>> bids_root, _ = collect_data(str(datadir / 'ds051'), '01',
+    ...                             bids_validate=False, bids_filters={'t1w':{'run': 1}})
+    >>> bids_root['t1w']  # doctest: +ELLIPSIS
+    ['.../ds051/sub-01/anat/sub-01_run-01_T1w.nii.gz']
     """
     if isinstance(bids_dir, BIDSLayout):
         layout = bids_dir
@@ -161,6 +167,9 @@ def collect_data(bids_dir, participant_label, task=None, echo=None,
         't1w': {'datatype': 'anat', 'suffix': 'T1w'},
         'roi': {'datatype': 'anat', 'suffix': 'roi'},
     }
+    bids_filters = bids_filters or {}
+    for acq, entities in bids_filters.items():
+        queries[acq].update(entities)
 
     if task:
         queries['bold']['task'] = task
@@ -304,3 +313,46 @@ def group_multiecho(bold_sess):
         action = getattr(ses_uids, 'append' if len(bold) > 2 else 'extend')
         action(bold)
     return ses_uids
+
+
+def check_pipeline_version(cvers, data_desc):
+    """
+    Searches for existing BIDS pipeline output and compares against current pipeline version.
+
+    .. testsetup::
+
+    >>> import json
+    >>> data = {"PipelineDescription": {"Version": "1.1.1rc5"}}
+    >>> desc_file = Path(tmpdir) / 'sample_dataset_description.json'
+    >>> _ = desc_file.write_text(json.dumps(data))
+
+    Parameters
+    ----------
+    cvers : :obj:`str`
+        Current pipeline version
+    data_desc : :obj:`str` or :class:`os.Pathlike`
+        Path to pipeline output's dataset_description.json
+
+    Examples
+    --------
+    >>> check_pipeline_version('1.1.1rc5', 'sample_dataset_description.json') is None
+    True
+    >>> check_pipeline_version('1.1.1rc5+129.gbe0e5158', 'sample_dataset_description.json')
+
+    >>> check_pipeline_version('1.2', 'sample_dataset_description.json')  # doctest: +ELLIPSIS
+    'Previous output generated ...'
+
+    Returns
+    -------
+    message : :obj:`str` or :obj:`None`
+        A warning string if there is a difference between versions, otherwise ``None``.
+
+    """
+    data_desc = Path(data_desc)
+    if not data_desc.exists():
+        return
+
+    desc = json.loads(data_desc.read_text())
+    dvers = desc.get("PipelineDescription", {}).get("Version", "0+unknown")
+    if Version(cvers).public != Version(dvers).public:
+        return "Previous output generated by version {} found.".format(dvers)
